#
# spec file for package python-autoflake
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           python-autoflake
Version:        1.5.3
Release:        2.1
Summary:        Program to removes unused Python imports and variables
License:        MIT
URL:            https://github.com/myint/autoflake
Source:         https://files.pythonhosted.org/packages/source/a/autoflake/autoflake-%{version}.tar.gz
BuildRequires:  %{python_module base >= 3.7}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module pyflakes >= 1.1.0}
BuildRequires:  %{python_module toml >= 0.10.2}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-pyflakes >= 1.1.0
Requires:       python-toml >= 0.10.2
Requires(post): update-alternatives
Requires(postun):update-alternatives
BuildArch:      noarch
%python_subpackages

%description
Autoflake removes unused imports and unused variables from Python
code. It makes use of pyflakes to do this.

By default, autoflake only removes unused imports for modules that
are part of the standard library. (Other modules may have side
effects that make them unsafe to remove automatically.) Removal of
unused variables is also disabled by default.

autoflake also removes useless pass statements.

%prep
%setup -q -n autoflake-%{version}
sed -i '1{/env python/d}' autoflake.py

%build
%pyproject_wheel

%install
%pyproject_install
%python_clone -a %{buildroot}%{_bindir}/autoflake
%fdupes %{buildroot}%{$python_sitelib}

%check
export LANG=en_US.UTF-8
%pyunittest -v test_autoflake

%post
%python_install_alternative autoflake

%postun
%python_uninstall_alternative autoflake

%files %{python_files}
%doc AUTHORS.rst README.md
%license LICENSE
%python_alternative %{_bindir}/autoflake
%{python_sitelib}/autoflake.py*
%pycache_only %{python_sitelib}/__pycache__/autoflake*.pyc
%{python_sitelib}/autoflake-%{version}*-info

%changelog
* Mon Jul 31 2023 Matej Cepl <mcepl@suse.com>
- Remove upstreamed patch rm_assert_failing_310.patch.
* Mon Sep 12 2022 Dirk Müller <dmueller@suse.com>
- reenable build for python38, issue got fixed in current release
* Fri Sep  9 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to v1.5.3
  * test_autoflake: use os.linesep in assertion
  * Make sure messages use os.linesep
  * test_autoflake: add a test for #129
  * autoflake: propagate the exit status instead of calling sys.exit
  * Renamed the head branch
  * Remove Makefile and reference to travis.yml
- Update to v1.5.2
  * Remove usage of deprecated distutils module
  * Also add support for removing RHS of unused variables.
  * Use the new sysconfig module instead of distutils
  * added option to remove RHS also when removing unused variables (#92)
* Sun Aug 28 2022 Ben Greiner <code@bnavigator.de>
- Update to v1.5.1
  * support for reading configuration from setup.cfg and
    pyproject.toml
  * new flag `--quiet`
  * drop support for old versions of Python (<3.7)
  * support for reading contents from stdin (prints the output to
    stdout, ideal for integration with editors)
  * support for parallel execution with `--jobs`
- Skip building Python 3.8: gh#PyCQA/autoflake#100
* Wed Feb 23 2022 Matej Cepl <mcepl@suse.com>
- Skip failing test for Python 3.10 (gh#PyCQA/autoflake#104)
* Mon Aug 31 2020 Steve Kowalik <steven.kowalik@suse.com>
- Update to 1.4:
  * No upstream changelog
- Switch from setup.py test to pytest
* Fri Sep 13 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 1.3.1:
  * no upstream changelog
* Thu May 16 2019 Meera Belur <mbelur@suse.com>
- Update to v1.3
  + No changes were provided
* Sun Feb 10 2019 John Vandenberg <jayvdb@gmail.com>
- Update to v1.2
  + Have `standard_paths` look in both platform-specific and
    platform-independent directories
    (replaces fix_standard_paths.patch)
  + Add LICENSE
  + Drop Python 3.3
- Remove unnecessary build dependency %%pythons
- Remove unused build dependency 'coverage'
* Wed Dec  5 2018 Jan Engelhardt <jengelh@inai.de>
- Use noun phrase in summary.
* Tue Dec  4 2018 Matej Cepl <mcepl@suse.com>
- Remove superfluous devel dependency for noarch package
* Wed May  9 2018 toddrme2178@gmail.com
- Add license file
- Use license tag
* Fri Oct 20 2017 toddrme2178@gmail.com
- initial version
- Add fix_standard_paths.patch
  * Fix for https://github.com/myint/autoflake/issues/32
